#
# spec file for package python-debtcollector
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pypi_name debtcollector
Name:           python-debtcollector
Version:        1.20.0
Release:        2.1
Summary:        A collection of Python deprecation patterns and strategies
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/developer/debtcollector/
Source0:        https://files.pythonhosted.org/packages/source/d/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python2-fixtures
BuildRequires:  python2-funcsigs >= 1.0.0
BuildRequires:  python2-pbr >= 2.0.0
BuildRequires:  python2-python-subunit
BuildRequires:  python2-setuptools
BuildRequires:  python2-stestr
BuildRequires:  python2-wrapt >= 1.7.0
BuildRequires:  python3-devel
BuildRequires:  python3-fixtures
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-python-subunit
BuildRequires:  python3-setuptools
BuildRequires:  python3-stestr
BuildRequires:  python3-wrapt >= 1.7.0
Requires:       python-pbr >= 2.0.0
Requires:       python-six >= 1.10.0
Requires:       python-wrapt >= 1.7.0
BuildArch:      noarch
%ifpython2
Requires:       python-funcsigs >= 1.0.0
%endif
%python_subpackages

%description
A collection of Python deprecation patterns and strategies that help
you collect your technical debt in a non-destructive manner. The goal
of this library is to provide well documented developer facing
deprecation patterns that start of with a basic set and can expand
into a larger set of patterns as time goes on. The desired output of
these patterns is to apply the warnings module to emit
DeprecationWarning or PendingDeprecationWarning or similar derivative
to developers using libraries (or potentially applications) about
future deprecations.

%package -n python-debtcollector-doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildRequires:  python-Sphinx
BuildRequires:  python2-openstackdocstheme
BuildRequires:  python3-openstackdocstheme

%description -n python-debtcollector-doc
A collection of Python deprecation patterns and strategies that help
you collect your technical debt in a non-destructive manner. The goal
of this library is to provide well documented developer facing
deprecation patterns that start of with a basic set and can expand
into a larger set of patterns as time goes on. The desired output of
these patterns is to apply the warnings module to emit
DeprecationWarning or PendingDeprecationWarning or similar derivative
to developers using libraries (or potentially applications) about
future deprecations.

This package contains documentation in HTML format.

%prep
%autosetup -n %{pypi_name}-%{version}
%py_req_cleanup
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
%python_build

# generate html doc
%{__python2} setup.py build_sphinx
# remove the Sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}

%check
%python_exec -m stestr.cli run

%install
%python_install

%files %{python_files}
%license LICENSE
%doc README.rst
%{python2_sitelib}/%{pypi_name}
%{python2_sitelib}/%{pypi_name}-*.egg-info

%files -n python-debtcollector-doc
%license LICENSE
%doc doc/build/html

%changelog
* Mon Oct  8 2018 cloud-devel@suse.de
- update to version 1.20.0
  - set default python to python3
  - fix tox python3 overrides
  - Update reno for stable/queens
  - pypy is not checked at gate
  - Trivial: Update pypi url to new url
  - Update links in README
  - Remove setting of version/release from releasenotes
  - remove obsolete tox environments
  - Switch to stestr
  - Updated from global requirements
  - add lower-constraints job
* Mon Sep  3 2018 dmueller@suse.com
- switch to stable/rocky template
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Thu Jan 18 2018 cloud-devel@suse.de
- update to version 1.19.0
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
* Tue Nov 21 2017 cloud-devel@suse.de
- update to version 1.18.0
  - Update reno for stable/pike
  - Updated from global requirements
* Thu Sep 28 2017 cloud-devel@suse.de
- update to version 1.17.1
  - Update .gitreview for stable/pike
  - Updated from global requirements
  - Update UPPER_CONSTRAINTS_FILE for stable/pike
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.17.0
  - Remove testscenarios from test-requirements.txt
  - Do not require oslotest for testing
  - Update URLs in documents according to document migration
  - rearrange existing documentation to fit the new standard layout
  - Update reno for stable/ocata
  - Remove pbr warnerrors in favor of sphinx check
  - Updated from global requirements
  - switch from oslosphinx to openstackdocstheme
  - Python 3.4 support has been removed
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 1.11.0:
  - Remove discover from test-requirements
  - Trivial: Remove 'MANIFEST.in'
  - Fix a typo in comment
  - Typo fix for module debtcollector
  - Drop *openstack/common* in flake8 exclude list
  - Add Constraints support
  - Add reno for release notes management
  - Add tests for decorated argspec preservation
  - Show team and repo badges on README
  - Update homepage with developer documentation page
  - Fix renamed_kwarg to preserve argspec
  - Add Python 3.5 classifier and venv
  - Drop babel as requirement since its not used
  - Updated from global requirements
- Switch to spec template from openstack/rpm-packaging project
* Tue Nov 15 2016 dmueller@suse.com
- update to 1.8.0:
  * Drop *openstack/common* in flake8 exclude list
  * Remove discover from test-requirements
  * Add Python 3.5 classifier and venv
  * Drop babel as requirement since its not used
  * Fix renamed_kwarg to preserve argspec
  * Add tests for decorated argspec preservation
  * Updated from global requirements
* Mon Feb 15 2016 dmueller@suse.com
- update to 1.3.0:
  * Updated from global requirements
  * Add debug testenv in tox
  * Add updated_kwarg_default_value decorator
  * Allow replacing a keyword argument
  * Add 'removed_class' class decorator
  * py26/py33 are no longer supported by Infra's CI
  * Add removals.remove note about metaclasses
  * Updated from global requirements
  * Update get_class_name from olso.utils
  * Remove Python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Add 'moved_read_only_property' descriptor
  * Add ability to disable warnings being emitted
  * Add a 'removed_property' descriptor class
  * No need for Oslo Incubator Sync
  * docs - Set pbr 'warnerrors' option for doc build
  * Include changelog/history in docs
  * tweak language in readme
  * Enhance the README
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
  * Activate pep8 check that _ is imported
  * Add a moved function helper
* Wed Sep  9 2015 tbechtold@suse.com
- update to 0.8.0:
  * Updated from global requirements
* Tue Aug  4 2015 tbechtold@suse.com
- update to 0.7.0
  * Updated from global requirements
  * Expose a top level 'deprecate' function
  * Add @removals.removed_kwarg on an __init__ method
  * Improve + test keyword argument @classmethod removal
  * Add example for removing a @classmethod
* Tue Jul 28 2015 tbechtold@suse.com
- update to 0.6.0:
  * Ensure doctesting and doc8 testing done in py27 env
  * Updated from global requirements
  * Fix quoting of examples
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
* Tue Jun  2 2015 tbechtold@suse.com
- Adjust Require versions according to requirements.txt
* Tue Jun  2 2015 tbechtold@suse.com
- Initial packaging
